# ForwardPlanProperties

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**forward_plan_reference_number** | **str** |  | 
**work_reference_number** | **str** |  | 
**forward_plan_status** | [**ForwardPlanStatusResponse**](ForwardPlanStatusResponse.md) |  | 
**forward_plan_status_string** | **str** |  | 
**work_centre_point** | [**GeoJSONCentrePoint**](GeoJSONCentrePoint.md) |  | 
**street** | **str** |  | 
**area** | **str** |  | [optional] 
**start_date** | **datetime** |  | 
**end_date** | **datetime** |  | 
**description_of_work** | **str** |  | 
**promoter_organisation** | **str** |  | 
**location_description** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

